@@ -53,5 +53,5 @@ def print_matrix_vector(
     b_string = f"{b_label} =\n{b.reshape((A.shape[0], 1))}"
     A_lines = A_string.splitlines()
     b_lines = b_string.splitlines()
-    for i in range(len(A_lines)):
+    for i, _ in enumerate(A_lines):
         print(A_lines[i].ljust(column_width) + b_lines[i].ljust(column_width))
